@@ -61,6 +61,8 @@ if env == "prod":
     rollbar.init(ROLLBAR_POST_CLIENT_ITEM, 'production', enabled=True, allow_logging_basic_config=False)
 elif env == "dev":
     rollbar.init(ROLLBAR_POST_CLIENT_ITEM, 'development', enabled=False, allow_logging_basic_config=False)
+elif env == "test":
+    rollbar.init(ROLLBAR_POST_CLIENT_ITEM, 'test', enabled=False, allow_logging_basic_config=False)
 else:
     raise Exception("Invalid GIGALIXIR_ENV")
 
@@ -81,7 +83,6 @@ def report_errors(f):
             f(*args, **kwds)
         except:
             logging.getLogger("gigalixir-cli").error(sys.exc_info()[1])
-            # rollbar.report_exc_info()
             rollbar.report_exc_info(sys.exc_info(), payload_data={'fingerprint': rollbar_fingerprint(sys.exc_info())})
             sys.exit(1)
     return wrapper
@@ -206,7 +207,7 @@ def detect_app():
 
 @click.group(cls=AliasedGroup, context_settings=CONTEXT_SETTINGS)
 # @click.group(cls=CatchAllExceptions(AliasedGroup, handler=handle_exception), context_settings=CONTEXT_SETTINGS)
-@click.option('--env', envvar='GIGALIXIR_ENV', default='prod', help="GIGALIXIR environment [prod, dev].")
+@click.option('--env', envvar='GIGALIXIR_ENV', default='prod', help="GIGALIXIR environment [prod, dev, test].")
 @click.pass_context
 def cli(ctx, env):
     ctx.obj = {}
@@ -219,6 +220,11 @@ def cli(ctx, env):
     elif env == "dev":
         stripe.api_key = 'pk_test_6tMDkFKTz4N0wIFQZHuzOUyW'
         host = "http://localhost:4000"
+    elif env == "test":
+        stripe.api_key = 'pk_test_6tMDkFKTz4N0wIFQZHuzOUyW'
+
+        # gets intercepted in tests
+        host = "https://api.gigalixir.com"
     else:
         raise Exception("Invalid GIGALIXIR_ENV")
 
@@ -330,7 +336,7 @@ def rollback(ctx, app_name, version):
 @cli.command(name='ps:remote_console')
 @click.option('-a', '--app_name', envvar="GIGALIXIR_APP")
 @click.option('-o', '--ssh_opts', default="", help='Command-line options to pass to ssh.')
-@click.option('-o', '--ssh_cmd', default="ssh", help='Which ssh command to use.')
+@click.option('-c', '--ssh_cmd', default="ssh", help='Which ssh command to use.')
 @click.pass_context
 @report_errors
 @detect_app_name
@@ -749,6 +755,18 @@ def send_reset_password_token(ctx, email):
     """
     gigalixir_user.get_reset_password_token(ctx.obj['host'], email)
 
+# @get.command()
+@cli.command(name='account:email:set')
+@click.option('-p', '--password', prompt=True, hide_input=True, confirmation_prompt=False)
+@click.option('-e', '--email', prompt=True)
+@click.pass_context
+@report_errors
+def send_reset_password_token(ctx, password, email):
+    """
+    Set account email
+    """
+    gigalixir_user.set_email(ctx.obj['host'], password, email)
+
 # @get.command()
 @cli.command(name='pg')
 @click.option('-a', '--app_name', envvar="GIGALIXIR_APP")
@@ -832,7 +850,7 @@ def delete_app(ctx, app_name, yes):
     """
     Deletes an app. Can not be undone. 
     """
-    logging.getLogger("gigalixir-cli").info("WARNING: Deleting an app can not be undone and the name can not be reused.")
+    logging.getLogger("gigalixir-cli").info("WARNING: Deleting an app can not be undone.")
     if yes or click.confirm('Do you want to delete your app (%s)?' % app_name):
         gigalixir_app.delete(ctx.obj['host'], app_name)
 
